Windows RC files — Translate Toolkit 2.2.0 documentation

# Windows RC files

New in version 1.2.

Windows .rc files, or resource files, are used to store translatable text, dialogs, menu, etc. for Windows applications. The format can be handled by the Translate Toolkit rc2po and po2rc.

## Conformance

The actual specification of .rc files is hard to come by. The parser was built using WINE .rc files as a reference. This was done as WINE is a good target for .rc translations. We are confident though that the extraction will prove robust for all .rc files.

## Useful resource

- RC converter
- ReactOS translation instructions

## Supported elements

- DIALOG, DIALOGEX: All translatables
- MENU: POPUP, MENUITEM
- STRINGTABLE
- LANGUAGE: We only parse the first language tag, further LANGUAGE section are ignored

## Bugs

- There may be problems with very deeply nested MENU’s
- LANGUAGE elements cannot yet be updated in po2rc (Issue 360)